@@ -11,21 +11,22 @@
 //Uses routines from Kapman sound manager (game.cpp)
 
 #include "KBlocksSound.h"
-#include "settings.h"
 
 #include <kgsound.h>
 
-#include <QDebug>
 #include <QStandardPaths>
 
+#include "KBlocks_debug.h"
+#include "settings.h"
+
 KBlocksSound::KBlocksSound()
 {
     m_blockFallSound = new KgSound(QStandardPaths::locate(
-                    QStandardPaths::DataLocation, "sounds/block-fall.ogg"));
+                    QStandardPaths::AppDataLocation, "sounds/block-fall.ogg"));
     m_blockMoveSound = new KgSound(QStandardPaths::locate(
-                    QStandardPaths::DataLocation, "sounds/block-move.ogg"));
+                    QStandardPaths::AppDataLocation, "sounds/block-move.ogg"));
     m_blockRemoveSound = new KgSound(QStandardPaths::locate(
-                    QStandardPaths::DataLocation, "sounds/block-remove.ogg"));
+                    QStandardPaths::AppDataLocation, "sounds/block-remove.ogg"));
     setSoundsEnabled(Settings::sounds());
 }
 
@@ -55,7 +56,7 @@ void KBlocksSound::playSound(Sound soundType)
             m_blockRemoveSound->start();
             break;
         default:
-            qDebug() << "Unknown Sound requested for playback.";
+            qCWarning(KBSound) << "Unknown Sound requested for playback.";
             break;
         }
     }
